@@ -5,32 +5,10 @@ use strict;
 use warnings;
 use Wx;
 
-require Exporter;
-use AutoLoader qw(AUTOLOAD);
+our $VERSION = '0.02';
 
-our @ISA = qw(Exporter);
-
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-
-# This allows declaration	use Wx::WebKit ':all';
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
-our %EXPORT_TAGS = ( 'all' => [ qw(
-	
-) ] );
-
-our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-
-our @EXPORT = qw(
-	
-);
-
-our $VERSION = '0.01';
-
-require XSLoader;
-XSLoader::load('Wx::WebKit', $VERSION);
+Wx::wx_boot('Wx::WebKit', $VERSION);
+package Wx::WebKitCtrl; our @ISA = 'Wx::Control';
 
 # Preloaded methods go here.
 
